@@ -44,6 +44,7 @@
 
 #include "../platform/hgw.h"
 #include "plugin.h"
+#include "i18n.h"
 
 static GtkWidget * load_plugin(void);
 static void unload_plugin(void);
@@ -54,7 +55,7 @@ static void plugin_callback(GtkWidget * menu_item, gpointer data);
 
 GConfClient * gcc = NULL;
 static GameStartupInfo gs;
-static GtkWidget * menu_items[4];
+static GtkWidget * menu_items[2];
 
 static StartupPluginInfo plugin_info = {
 	load_plugin,
@@ -102,7 +103,7 @@ static void set_rom(const char * rom_file)
 	if (current_rom_file) g_free(current_rom_file);
 	if (!rom_file || strlen(rom_file) == 0) {
 		current_rom_file = NULL;
-		set_rom_label("<no rom selected>");
+		set_rom_label(_("<no rom selected>"));
 		return;
 	}
 
@@ -166,15 +167,17 @@ static void select_rom_callback(GtkWidget * button, gpointer data)
 	}
 }
 
+#if MAEMO_VERSION < 5
 static void controls_item_callback(GtkWidget * button, gpointer data)
 {
 	controls_setup();
 	controls_dialog(get_parent_window());
 }
+#endif
 
-static void advanced_item_callback(GtkWidget * button, gpointer data)
+static void settings_item_callback(GtkWidget * button, gpointer data)
 {
-	advanced_dialog(get_parent_window());
+	settings_dialog(get_parent_window());
 }
 
 static void about_item_callback(GtkWidget * button, gpointer data)
@@ -183,7 +186,10 @@ static void about_item_callback(GtkWidget * button, gpointer data)
 }
 
 #if MAEMO_VERSION >= 5
-/* Called for each of the play/restart/continue buttons */
+#include <gdk/gdkx.h>
+#include <X11/Xatom.h>
+
+/** Called for each of the play/restart/continue buttons */
 static void found_ogs_button_callback(GtkWidget *widget, gpointer data)
 {
 	hildon_gtk_widget_set_theme_size(widget,
@@ -192,6 +198,24 @@ static void found_ogs_button_callback(GtkWidget *widget, gpointer data)
 	gtk_box_set_child_packing(GTK_BOX(data), widget,
 		FALSE, FALSE, 0, GTK_PACK_START);
 }
+/** Converts the window into a stackable one */
+static void plugin_realized_callback(GtkWidget *widget, gpointer data)
+{
+	GdkDisplay *display;
+    Atom atom;
+    unsigned long val = 0;
+	GtkWidget* window = gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW);
+
+    /* Set additional property "_HILDON_STACKABLE_WINDOW", 
+    	to allow the WM to manage it as a stackable window. */
+    display = gdk_drawable_get_display(window->window);
+    atom = gdk_x11_get_xatom_by_name_for_display (display,
+    				"_HILDON_STACKABLE_WINDOW");
+    XChangeProperty(GDK_DISPLAY_XDISPLAY(display),
+    				 GDK_WINDOW_XID(window->window),
+    				 atom, XA_INTEGER, 32, PropModeReplace,
+                     (unsigned char *) &val, 1);
+}
 #endif
 
 static GtkWidget * load_plugin(void)
@@ -207,7 +231,7 @@ static GtkWidget * load_plugin(void)
 	select_rom_btn = HILDON_BUTTON(hildon_button_new_with_text(
 		HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_THUMB_HEIGHT,
 		HILDON_BUTTON_ARRANGEMENT_VERTICAL,
-		"ROM",
+		_("ROM"),
 		NULL));
 	hildon_button_set_alignment(select_rom_btn, 0.0f, 0.5f, 0.9f, 0.2f);
 
@@ -225,7 +249,7 @@ static GtkWidget * load_plugin(void)
 #else
 {
 	GtkWidget* rom_hbox = gtk_hbox_new(FALSE, HILDON_MARGIN_DEFAULT);
-	select_rom_btn = GTK_BUTTON(gtk_button_new_with_label("Select ROM..."));
+	select_rom_btn = GTK_BUTTON(gtk_button_new_with_label(_("Select ROM...")));
 	gtk_widget_set_size_request(GTK_WIDGET(select_rom_btn),	180, 46);
 	rom_label = GTK_LABEL(gtk_label_new(NULL));
 
@@ -242,12 +266,13 @@ static GtkWidget * load_plugin(void)
 	sound_check =
 		HILDON_CHECK_BUTTON(hildon_check_button_new(
 			HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT));
-	gtk_button_set_label(GTK_BUTTON(sound_check), "Sound");
+	gtk_button_set_label(GTK_BUTTON(sound_check), _("Sound"));
 
 	framerate_picker = HILDON_PICKER_BUTTON(hildon_picker_button_new(
 		HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT,
 		HILDON_BUTTON_ARRANGEMENT_HORIZONTAL));
-	hildon_button_set_title(HILDON_BUTTON(framerate_picker), "Target framerate");
+	hildon_button_set_title(HILDON_BUTTON(framerate_picker),
+		_("Target framerate"));
 
 	HildonTouchSelector* framerate_sel =
 		HILDON_TOUCH_SELECTOR(hildon_touch_selector_new_text());
@@ -264,11 +289,11 @@ static GtkWidget * load_plugin(void)
 	display_fps_check =
 		HILDON_CHECK_BUTTON(hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT));
 	gtk_button_set_label(GTK_BUTTON(display_fps_check),
-		"Show while in game");
+		_("Show while in game"));
 	turbo_check =
 		HILDON_CHECK_BUTTON(hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT));
 	gtk_button_set_label(GTK_BUTTON(turbo_check),
-		"Turbo mode");
+		_("Turbo mode"));
 
 	gtk_box_pack_start_defaults(framerate_sel_box, GTK_WIDGET(display_fps_check));
 	gtk_box_pack_start_defaults(framerate_sel_box, GTK_WIDGET(turbo_check));
@@ -283,12 +308,12 @@ static GtkWidget * load_plugin(void)
 {
 	GtkBox* opt_hbox1 = GTK_BOX(gtk_hbox_new(FALSE, HILDON_MARGIN_DEFAULT));
 	sound_check =
-		GTK_CHECK_BUTTON(gtk_check_button_new_with_label("Enable sound"));
+		GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Enable sound")));
 
 	turbo_check =
-		GTK_CHECK_BUTTON(gtk_check_button_new_with_label("Turbo mode"));
+		GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Turbo mode")));
 	display_fps_check =
-		GTK_CHECK_BUTTON(gtk_check_button_new_with_label("Display framerate"));
+		GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Display framerate")));
 	speedhacks_combo =
 		GTK_COMBO_BOX(gtk_combo_box_new_text());
 
@@ -307,11 +332,11 @@ static GtkWidget * load_plugin(void)
 	GtkBox* opt_hbox2 = GTK_BOX(gtk_hbox_new(FALSE, HILDON_MARGIN_DEFAULT));
 
 	accu_check =
-		GTK_CHECK_BUTTON(gtk_check_button_new_with_label("Accurate graphics"));
+		GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("Accurate graphics")));
 
 	framerate_combo =
 		GTK_COMBO_BOX(gtk_combo_box_new_text());
-	GtkWidget* framerate_box = hildon_caption_new(NULL, "Framerate:",
+	GtkWidget* framerate_box = hildon_caption_new(NULL, _("Framerate:"),
 		GTK_WIDGET(framerate_combo), NULL, HILDON_CAPTION_OPTIONAL);
 
 	gtk_combo_box_append_text(framerate_combo, "Auto");
@@ -320,9 +345,9 @@ static GtkWidget * load_plugin(void)
 		sprintf(buffer, "%d-%d", 50/i, 60/i);
 		gtk_combo_box_append_text(framerate_combo, buffer);
 	}
-	gtk_combo_box_append_text(speedhacks_combo, "No speedhacks");
-	gtk_combo_box_append_text(speedhacks_combo, "Safe hacks only");
-	gtk_combo_box_append_text(speedhacks_combo, "All speedhacks");
+	gtk_combo_box_append_text(speedhacks_combo, _("No speedhacks"));
+	gtk_combo_box_append_text(speedhacks_combo, _("Safe hacks only"));
+	gtk_combo_box_append_text(speedhacks_combo, _("All speedhacks"));
 
 	gtk_box_pack_start(opt_hbox2, GTK_WIDGET(accu_check), FALSE, FALSE, 0);
 	gtk_box_pack_start(opt_hbox2, GTK_WIDGET(framerate_box), TRUE, FALSE, 0);
@@ -358,6 +383,11 @@ static GtkWidget * load_plugin(void)
 
 	set_rom(gconf_client_get_string(gcc, kGConfRomFile, NULL));
 
+#if MAEMO_VERSION == 5
+	g_signal_connect_after(G_OBJECT(parent), "realize",
+						G_CALLBACK(plugin_realized_callback), NULL);
+#endif
+
 	// Connect signals
 	g_signal_connect(G_OBJECT(select_rom_btn), "clicked",
 					G_CALLBACK(select_rom_callback), NULL);
@@ -416,22 +446,18 @@ static GtkWidget **load_menu(guint *nitems)
 	const HildonSizeType button_size =
 		HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH;
 	menu_items[0] = hildon_gtk_button_new(button_size);
-	gtk_button_set_label(GTK_BUTTON(menu_items[0]), "Settings…");
+	gtk_button_set_label(GTK_BUTTON(menu_items[0]), _("Settings…"));
 	menu_items[1] = hildon_gtk_button_new(button_size);
-	gtk_button_set_label(GTK_BUTTON(menu_items[1]), "Controls…");
-	menu_items[2] = hildon_gtk_button_new(button_size);
-	gtk_button_set_label(GTK_BUTTON(menu_items[2]), "About…");
-	*nitems = 3;
+	gtk_button_set_label(GTK_BUTTON(menu_items[1]), _("About…"));
+	*nitems = 2;
 
 	g_signal_connect(G_OBJECT(menu_items[0]), "clicked",
-					G_CALLBACK(advanced_item_callback), NULL);
+					G_CALLBACK(settings_item_callback), NULL);
 	g_signal_connect(G_OBJECT(menu_items[1]), "clicked",
-					G_CALLBACK(controls_item_callback), NULL);
-	g_signal_connect(G_OBJECT(menu_items[2]), "clicked",
 					G_CALLBACK(about_item_callback), NULL);
 #else
-	menu_items[0] = gtk_menu_item_new_with_label("Settings");
-	menu_items[1] = gtk_menu_item_new_with_label("About…");
+	menu_items[0] = gtk_menu_item_new_with_label(_("Settings"));
+	menu_items[1] = gtk_menu_item_new_with_label(_("About…"));
 	*nitems = 2;
 
 	GtkMenu* settings_menu = GTK_MENU(gtk_menu_new());
@@ -439,17 +465,17 @@ static GtkWidget **load_menu(guint *nitems)
 		GTK_WIDGET(settings_menu));
 
 	GtkMenuItem* controls_item =
-		GTK_MENU_ITEM(gtk_menu_item_new_with_label("Controls…"));
+		GTK_MENU_ITEM(gtk_menu_item_new_with_label(_("Controls…")));
 	gtk_menu_append(GTK_MENU(settings_menu), GTK_WIDGET(controls_item));
 
 	GtkMenuItem* advanced_item =
-		GTK_MENU_ITEM(gtk_menu_item_new_with_label("Advanced…"));
+		GTK_MENU_ITEM(gtk_menu_item_new_with_label(_("Advanced…")));
 	gtk_menu_append(GTK_MENU(settings_menu), GTK_WIDGET(advanced_item));
 
 	g_signal_connect(G_OBJECT(controls_item), "activate",
 					G_CALLBACK(controls_item_callback), NULL);
 	g_signal_connect(G_OBJECT(advanced_item), "activate",
-					G_CALLBACK(advanced_item_callback), NULL);
+					G_CALLBACK(settings_item_callback), NULL);
 	g_signal_connect(G_OBJECT(menu_items[1]), "activate",
 					G_CALLBACK(about_item_callback), NULL);
 #endif
@@ -505,12 +531,12 @@ static void plugin_callback(GtkWidget * menu_item, gpointer data)
 			}
 			if (!current_rom_file) {
 				GtkWidget* note = hildon_note_new_information(get_parent_window(),
-					"No ROM selected");
+					_("No ROM selected"));
 				gtk_dialog_run(GTK_DIALOG(note));
 				gtk_widget_destroy(note);
 			} else if (!current_rom_file_exists) {
 				GtkWidget* note = hildon_note_new_information(get_parent_window(),
-					"ROM file does not exist");
+					_("ROM file does not exist"));
 				gtk_dialog_run(GTK_DIALOG(note));
 				gtk_widget_destroy(note);
 			}
